@@ -9,7 +9,7 @@ This src/ package now only contains application-specific utilities.
 __version__ = "0.1.0"
 
 # Only export utilities - DFM module is now in dfm_python package
-from .utils import summarize
+from dfm_python.utils import summarize
 
 __all__ = [
     'summarize',
