@@ -513,6 +513,7 @@ def run_all_tests():
         ('em_step_dimensions', test_em_step_dimensions),
         ('init_conditions_basic', test_init_conditions_basic),
         ('matlab_comparison', test_matlab_comparison),
+        ('multi_block_different_factors', test_multi_block_different_factor_counts),
     ]
     
     for name, func in test_funcs:
@@ -715,5 +716,99 @@ def test_init_conditions_blocks():
     return True
 
 
+def test_multi_block_different_factor_counts():
+    """
+    Test for bug fix: multi-block models with different factor counts.
+    
+    This test reproduces the bug where ff variable from previous block
+    iteration caused dimension mismatch when stacking arrays.
+    
+    Bug scenario:
+    - Block 0: r_i=3, creates ff with width 3*pC
+    - Block 1: r_i=2, tries to use ff from block 0 (width 3*pC) 
+               with np.zeros(width 2*pC) -> dimension mismatch
+    
+    Fix: Reset ff = None at start of each block iteration.
+    """
+    print("\n" + "="*70)
+    print("Testing multi-block with different factor counts (bug fix)")
+    print("="*70)
+    
+    np.random.seed(42)
+    T = 100  # Time periods
+    N = 15   # Total series
+    
+    # Create synthetic data
+    x = np.random.randn(T, N)
+    
+    # Create blocks: 3 blocks with different factor counts
+    # Block 0: 5 series, 3 factors
+    # Block 1: 5 series, 2 factors  
+    # Block 2: 5 series, 2 factors
+    blocks = np.zeros((N, 3), dtype=int)
+    blocks[0:5, 0] = 1   # First 5 series in block 0
+    blocks[5:10, 1] = 1  # Next 5 series in block 1
+    blocks[10:15, 2] = 1 # Last 5 series in block 2
+    # All series also load on block 0 (global factor)
+    blocks[:, 0] = 1
+    
+    # Different factor counts per block (this triggers the bug)
+    r = np.array([3, 2, 2])  # 3 factors, 2 factors, 2 factors
+    p = 1  # AR lag
+    pC = max(p, 1)  # Will be 1
+    
+    # Setup other parameters
+    opt_nan = {'method': 2, 'k': 3}
+    nQ = 0  # All monthly
+    i_idio = np.ones(N)
+    Rcon = None
+    q = None
+    
+    # This should NOT raise ValueError about dimension mismatch
+    try:
+        A, C, Q, R, Z_0, V_0 = init_conditions(
+            x, r, p, blocks, opt_nan, Rcon, q, nQ, i_idio
+        )
+        
+        # Verify outputs are valid
+        assert A is not None, "A should not be None"
+        assert C is not None, "C should not be None"
+        assert Q is not None, "Q should not be None"
+        assert R is not None, "R should not be None"
+        
+        # Verify dimensions
+        # State dimension = sum(r_i * ppC) + monthly_idio + quarterly_idio * 5
+        # where ppC = max(p, pC) and pC = 1 when Rcon is None
+        ppC = max(p, 1)  # pC = 1 when Rcon is None
+        expected_state_dim = sum(r) * ppC + N + 5 * nQ  # factors + monthly_idio + quarterly_idio*5
+        assert A.shape == (expected_state_dim, expected_state_dim), \
+            f"A shape {A.shape} != expected {(expected_state_dim, expected_state_dim)}"
+        assert C.shape == (N, expected_state_dim), \
+            f"C shape {C.shape} != expected {(N, expected_state_dim)}"
+        
+        # Verify no NaN/Inf
+        assert np.all(np.isfinite(A)), "A contains NaN/Inf"
+        assert np.all(np.isfinite(C)), "C contains NaN/Inf"
+        assert np.all(np.isfinite(Q)), "Q contains NaN/Inf"
+        assert np.all(np.isfinite(R)), "R contains NaN/Inf"
+        
+        print("    ✓ Multi-block init_conditions with different factor counts: PASSED")
+        print(f"    ✓ State dimension: {expected_state_dim}")
+        print(f"    ✓ A shape: {A.shape}")
+        print(f"    ✓ C shape: {C.shape}")
+        
+        return True
+        
+    except ValueError as e:
+        if "dimension" in str(e).lower() and "match" in str(e).lower():
+            print(f"    ✗ FAILED: Dimension mismatch error still present!")
+            print(f"    Error: {e}")
+            raise
+        else:
+            # Other ValueError is OK (e.g., insufficient data)
+            print(f"    ⚠ Warning: {e}")
+            return True
+
+
 if __name__ == '__main__':
     run_all_tests()
